@@ -35,30 +35,18 @@ class BaseApiTest(APITransactionTestCase):
 
     def uuid_file_path_regex(self, prefix, pk, name, extension):
         uuid_regex = r"[0-9a-f]{8}\-[0-9a-f]{4}\-4[0-9a-f]{3}\-[89ab][0-9a-f]{3}\-[0-9a-f]{12}"
-        return re.compile(
-            r"^{prefix}/{pk}/{name}_{uuid}\.{extension}$".format(
-                prefix=prefix,
-                pk=pk,
-                name=name,
-                extension=extension,
-                uuid=uuid_regex,
-            )
-        )
+        return re.compile(fr"^{prefix}/{pk}/{name}_{uuid_regex}\.{extension}$")
 
     def assertUUIDFilePath(self, prefix, name, extension, pk, file):  # pylint: disable=invalid-name
         pattern = self.uuid_file_path_regex(prefix=prefix, pk=pk, name=name, extension=extension)
         self.assertTrue(pattern.match(str(file)))
 
-    def assertResponseList(self, expected_items: List[Dict], response):
-        count = response.json()["count"]
-        msg = f"Expected to receive {len(expected_items)} items, but metadata indicates {count} items"
-        self.assertEqual(len(expected_items), count, msg)
-
+    def assertResponseList(self, expected_items: List[Dict], response, response_key: str = "results"):
         self.assertResponse(
             expected_status=status.HTTP_200_OK,
             expected_body=expected_items,
             response=response,
-            response_key="results",
+            response_key=response_key,
         )
 
     def assertResponseDetail(self, expected_item: Dict, response):
